@@ -8,6 +8,10 @@ def add_perm(name, pred):
     permissions.add_rule(name, pred)
 
 
+def set_perm(name, pred):
+    permissions.set_rule(name, pred)
+
+
 def remove_perm(name):
     permissions.remove_rule(name)
 
@@ -21,7 +25,7 @@ def has_perm(name, *args, **kwargs):
 
 
 class ObjectPermissionBackend(object):
-    def authenticate(self, username, password):
+    def authenticate(self, *args, **kwargs):
         return None
 
     def has_perm(self, user, perm, *args, **kwargs):
