@@ -1,23 +1,21 @@
-import inspect
 import logging
 import operator
 import threading
 from functools import partial, update_wrapper
-from warnings import warn
+
+from .compat import inspect
 
 
 logger = logging.getLogger('rules')
 
 
-class SkipPredicate(Exception):
-    """
-    Use to reject usage of a predicate.
-    """
-    def __init__(self, *args, **kwargs):
-        warn('Skipping predicates by raising the SkipPredicate exception '
-             'has been deprecated. Return `None` from your predicate instead.',
-             DeprecationWarning)
-        super(SkipPredicate, self).__init__(*args, **kwargs)
+def assert_has_kwonlydefaults(fn, msg):
+    argspec = inspect.getfullargspec(fn)
+    if hasattr(argspec, 'kwonlyargs'):
+        if not argspec.kwonlyargs:
+            return
+        if not argspec.kwonlydefaults or len(argspec.kwonlyargs) > len(argspec.kwonlydefaults.keys()):
+            raise TypeError(msg)
 
 
 class Context(dict):
@@ -53,26 +51,29 @@ class Predicate(object):
         #   - fn(obj=None)
         #   - fn()
         assert callable(fn), 'The given predicate is not callable.'
+        innerfn = fn
         if isinstance(fn, Predicate):
             fn, num_args, var_args, name = fn.fn, fn.num_args, fn.var_args, name or fn.name
+            innerfn = fn
         elif isinstance(fn, partial):
-            argspec = inspect.getargspec(fn.func)
+            innerfn = fn.func
+            argspec = inspect.getfullargspec(innerfn)
             var_args = argspec.varargs is not None
             num_args = len(argspec.args) - len(fn.args)
-            if inspect.ismethod(fn.func):
+            if inspect.ismethod(innerfn):
                 num_args -= 1  # skip `self`
             name = fn.func.__name__
         elif inspect.ismethod(fn):
-            argspec = inspect.getargspec(fn)
+            argspec = inspect.getfullargspec(fn)
             var_args = argspec.varargs is not None
             num_args = len(argspec.args) - 1  # skip `self`
         elif inspect.isfunction(fn):
-            argspec = inspect.getargspec(fn)
+            argspec = inspect.getfullargspec(fn)
             var_args = argspec.varargs is not None
             num_args = len(argspec.args)
         elif isinstance(fn, object):
-            callfn = getattr(fn, '__call__')
-            argspec = inspect.getargspec(callfn)
+            innerfn = getattr(fn, '__call__')
+            argspec = inspect.getfullargspec(innerfn)
             var_args = argspec.varargs is not None
             num_args = len(argspec.args) - 1  # skip `self`
             name = name or type(fn).__name__
@@ -81,6 +82,7 @@ class Predicate(object):
             raise TypeError('Incompatible predicate.')
         if bind:
             num_args -= 1
+        assert_has_kwonlydefaults(innerfn, 'The given predicate is missing defaults for keyword-only arguments')
         assert num_args <= 2, 'Incompatible predicate.'
         self.fn = fn
         self.num_args = num_args
@@ -141,13 +143,6 @@ class Predicate(object):
         except IndexError:
             return None
 
-    def skip(self):
-        """
-        Use this method in a predicate body to signal that it should be
-        ignored for the current invocation.
-        """
-        raise SkipPredicate()
-
     def test(self, obj=NO_VALUE, target=NO_VALUE):
         """
         The canonical method to invoke predicates.
@@ -214,11 +209,9 @@ class Predicate(object):
             callargs = args[:self.num_args]
         if self.bind:
             callargs = (self,) + callargs
-        try:
-            result = self.fn(*callargs)
-            result = None if result is None else bool(result)
-        except SkipPredicate:
-            result = None
+
+        result = self.fn(*callargs)
+        result = None if result is None else bool(result)
 
         logger.debug('  %s = %s', self, 'skipped' if result is None else result)
         return result
